/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIDOMWindow.idl"

// interface for accessing RDF-specific data from the window datasource
[scriptable, uuid(3722A5B9-5323-4ed0-BB1A-8299F27A4E89)]
interface nsIWindowDataSource : nsISupports
{
    /**
     * for the given resource name, return the window
     */
    nsIDOMWindow getWindowForResource(in string inResource);
};
